
# Audit Committee Charter

## Committee Membership:
The Audit Committee of TSYS Group (the “Group”) shall be comprised of at least three directors, each of whom the Board has determined has no 
material relationship with the Group and each of whom is otherwise “independent” under the rules of the New York Stock Exchange, Inc. 
and Rule 10A-3 under the Securities Exchange Act of 1934

The Board shall also determine that each member is “financially literate,” and that one member of the Audit Committee has 
“accounting or related financial management expertise,” as such qualifications are interpreted by the Board of Directors in 
its business judgment, and whether any member of the Audit Committee is an “audit committee financial expert,” as defined by the
rules of Securities and Exchange Commission (the “SEC”). 

If the Board has determined that a member of the Audit Committee is an audit committee financial expert, it may presume that such member 
has accounting or related financial management expertise.

No director may serve as a member of the Audit Committee if such director serves on the audit committees of two or more other entities.

Members shall be appointed by the Board and shall serve at the pleasure of the Board and for such term or terms as the Board may determine.

## Purpose

The purposes of the Audit Committee are to:

### assist Board oversight 

Ensuring:

* the integrity of the Group’s financial statements
* the Group’s compliance with legal and regulatory requirements
* the independent auditors’ qualifications and independence
* the performance of the independent auditors and the Group’s internal audit function
* assist in the preparation of the Group Annual Report 

The function of the Committee is oversight of the various components of Auditing and Reporting.

Management of the Group component entities is responsible for the preparation, presentation and integrity of the Group’s financial statements.  
Management is responsible for maintaining appropriate accounting and financial reporting policies and internal controls and procedures that 
provide for compliance with accounting standards and applicable laws and regulations. 

The independent auditors are responsible for planning and carrying out a proper audit of the Group’s consolidated annual financial statements, 
reviews of the Group’s consolidated quarterly financial statements and other procedures. 

In fulfilling their responsibilities hereunder, it is recognized that members of the Committee are not fulltime employees of the Group and are not, 
and do not represent themselves to be, performing the functions of auditors or Management. 

As such, it is not the duty or responsibility of the Committee or its members to conduct “field work” or other types of auditing or accounting
reviews or procedures or to set auditor independence standards.

The independent auditors shall submit to the Committee annually a formal written statement (the “Auditors’ Statement”) describing: 

* the auditors’ internal quality-control procedures
* any material issues raised by the most recent internal quality-control review or peer review of the auditors
* any inquiry or investigation by governmental or professional authorities, within the preceding five years, respecting one or more independent audits 
carried out by the auditors and any steps taken to deal with any such issues
* all relationships between the independent auditors and the Group (in particular but not limited to any consulting agreements and accounting services)


## Committee Duties and Responsibilities

To carry out its purposes, the Audit Committee shall have the following duties and responsibilities

### with respect to the independent auditors

* to be directly responsible for the appointment, compensation, retention and oversight of the work of the independent auditors 
(including the resolution of disagreements between management and the independent auditors regarding financial reporting), 
who shall report directly to the Audit Committee

* to be directly responsible for the appointment, compensation, retention and oversight of the work of any public accounting firm used 
by the Group, and have the right to request that such firm shall report directly to the Audit Committee if the Committee deems it necessary

* to pre-approve, or to adopt appropriate procedures to pre-approve, all audit and non-audit services to be provided by the independent auditors and 
accounting firms

* to ensure that the independent auditors prepare and deliver annually an Auditors’ Statement (it being understood that the independent auditors are
responsible for the accuracy and completeness of this Statement), and to discuss with the independent auditors any relationships or services disclosed
in this Statement that may impact the quality of audit services or the objectivity and independence of the Group’s independent auditors

* to obtain from the independent auditors in connection with any audit a timely report relating to the Group’s annual audited financial statements
describing all critical accounting policies and practices used, all alternative treatments of financial information within generally accepted accounting
principles that have been discussed with management, ramifications of the use of such alternative disclosures and treatments, and the treatment
preferred by the independent auditors, and any material written communications between the independent auditors and management, such
as any “management” letter or schedule of unadjusted differences

* to take into account the opinions of management and the Group’s director of internal audit in assessing the independent auditors’
qualifications, performance and independence with respect to the internal audit function

* to review the appointment and replacement of the Group’s director of internal audit

* to advise the director of internal audit that he or she is expected to provide to the Audit Committee summaries of and, as appropriate, the significant
reports resulting from audits performed by internal audit and management’s responses thereto

* to annually approve the Internal Audit plan and charter with respect to financial reporting principles and policies and internal controls and
procedures

* to advise management, the director of internal audit and the independent auditors that they are expected to provide to the Audit Committee a timely
analysis of significant financial reporting issues and practices

* to consider any reports or communications (and management’s and/or internal audit’s responses thereto) submitted to the Audit Committee by the
independent auditors required by or referred to in PCAOB Auditing Standard No. 16, as it may be modified or supplemented, including reports
and communication related to:

    * deficiencies noted in the audit in the design or operation of internal controls
    * consideration of fraud in a financial statement audit
   * detection of illegal acts
   * the independent auditors’ responsibility under generally accepted auditing standards
   * any restriction on audit scope
   * significant accounting policies
   * significant issues discussed with the national office respecting auditing or accounting issues presented by the engagement
   * management judgments and accounting estimates
   * any accounting adjustments arising from the audit that were noted or proposed by the auditors but were passed (as immaterial or
otherwise)
   * disagreements with management
   * consultation by management with other accountants
   * difficulties encountered with management in performing the audit
   * the independent auditors’ judgments about the quality of the entity’s accounting principles
   * reviews of interim financial information conducted by the independent auditors
   * going concern uncertainties
   * departures from the standard auditor’s report
   * overview of the audit strategy, timing of the audit, and significant risks
   * the responsibilities, budget and staffing of the Group’s internal audit function

* to meet with management, the independent auditors and, if appropriate, the director of internal audit:

   * discuss the scope of the annual audit
   * discuss the annual audited financial statements and quarterly financial statements, including the Group’s disclosures under
  “Management’s Discussion and Analysis of Financial Condition and Results of Operations”; discuss any significant matters arising 
  from any audit, including any audit problems or difficulties, whether raised by management, director of internal audit or the 
  independent auditors, relating to the Group’s financial statements
   * to discuss any difficulties the independent auditors encountered in the course of the audit, including any restrictions on their activities
  or access to requested information and any significant disagreements with management
   * to discuss any “management” or “internal control” letter issued, or proposed to be issued, by the independent auditors to the Group 
   * to review the form of opinion the independent auditors propose to render to the Board of Directors and stakeholders; 

* to discuss, as appropriate: 

   * any major issues regarding accounting principles and financial statement presentations, including any significant changes in the Group’s selection 
or application of accounting principles
   * any major issues as to the adequacy of the Group’s internal controls and any special audit steps adopted in light of material control deficiencies;
   * analyses prepared by management and/or the independent auditors setting forth significant financial reporting issues and judgments made in
connection with the preparation of the financial statements, including analyses of the effects of alternative GAAP methods on
the financial statements 
   * the effect of regulatory and accounting initiatives, as well as off-balance sheet structures, on the financial statements of the Group;

* to inquire of the Group’s Chief Executive Officers and Chief Financial Officers as to the existence of any significant deficiencies and material
weaknesses in the design or operation of internal control over financial reporting which are reasonably likely to adversely affect the Group’s
ability to record, process, summarize and report financial information and any fraud, whether or not material, that involves management or other
employees who have a significant role in the Group’s internal control over financial reporting

* to discuss guidelines and policies governing the process by which senior management of the Group and the relevant sections of the Group
assess and manage the Group’s exposure to risk, and to discuss the Group’s major financial risk exposures and the steps management has
taken to monitor and control such exposures

* to obtain from the independent auditors assurance that the audit was conducted in a manner consistent with Section 10A of the Securities
Exchange Act of 1934, as amended, which sets forth certain procedures to be followed in any audit of financial statements required under the
Securities Exchange Act of 1934

* to discuss with senior management of the Group any significant legal, compliance or regulatory matters that may have a material effect on the
financial statements or the Group’s business, financial statements or compliance policies, including material notices to or inquiries received from
governmental agencies

* to discuss the type and presentation of information to be included in finanical releases and disclosures

* to establish procedures for the receipt, retention and treatment of complaints received by the Group regarding accounting, internal accounting
controls or auditing matters, and for the confidential, anonymous submission by Group employees of concerns regarding questionable
accounting or auditing matters

* to review and discuss any reports concerning material violations submitted to it by Group attorneys or outside counsel pursuant to the SEC attorney
professional responsibility rules (17 C.F.R. Part 205), or otherwise

* to establish hiring policies for employees or former employees of the independent auditors

* to review and approve all related-party transactions that are required to be disclosed under Item 404(a) of Regulation S-K.

### with respect to reporting and recommendations

* to prepare any report or other disclosures, including any recommendation of the Audit Committee, required by the rules of the SEC to be included in
the Group’s annual report;
* to prepare and issue the evaluation required under “Performance Evaluation” below
* to report its activities to the full Board of Directors on a regular basis and to make such recommendations with respect to the above and 
other matters as the Audit Committee may deem necessary or appropriate.

### Committee Structure and Operations

The Audit Committee shall designate one member of the Committee as its chairperson. The Audit Committee shall meet once every quarter, 
or more frequently if circumstances dictate, to discuss with management the annual audited financial statements and quarterly financial
statements, as applicable. 

The Audit Committee should meet separately periodically with management, the director of internal audit and the independent auditors 
to discuss any matters that the Audit Committee or any of these persons or firms believe should be discussed privately.

The Audit Committee may request any officer or employee of the Group or the Group’s outside counsel or independent auditors to attend a 
meeting of the Audit Committee or to meet with any members of, or consultants to, the Audit Committee. 

Members of the Audit Committee may participate in a meeting of the Audit Committee by means of conference call or similar communications equipment by 
means of which all persons participating in the meeting can hear each other.

## Performance Evaluation

The Audit Committee shall prepare and review with the Board an annual performance evaluation of the Audit Committee, which evaluation 
shall compare the performance of the Audit Committee with the requirements of this charter. 

The performance evaluation shall also recommend to the Board any improvements to the Audit Committee’s charter deemed necessary
or desirable by the Audit Committee. The performance evaluation by the Audit Committee shall be conducted in such manner as the Audit 
Committee deems appropriate. 

The report to the Board may take the form of an oral report by the chairperson of the Audit Committee or any other member of the Audit Committee 
designated by the Audit Committee to make this report.

## Resources and Authority of the Audit Committee

The Audit Committee shall have the resources and authority appropriate to discharge its duties and responsibilities, including the 
authority to select, retain, terminate, and approve the fees and other retention terms of special or independent counsel, accountants 
or other experts and advisors, as it deems necessary or appropriate, without seeking approval of the Board or
management.

The Group shall provide for appropriate funding, as determined by the Audit Committee, in its capacity as a committee of the Board, for payment of:

* Compensation to the independent auditors and any other public accounting firm engaged for the purpose of preparing or issuing an 
audit report or performing other audit, review or attest services for the Company

* Compensation of any advisers employed by the Audit Committee

* Ordinary administrative expenses of the Audit Committee that are necessary or appropriate in carrying out its duties.
