# ARTICLE XII - SOCIOCRACY PRINCIPLES

## 12.1 Sociocracy Framework

The Company and each Series shall implement governance structures and processes based on sociocracy principles. Sociocracy provides a framework for effective governance, transparent decision-making, and equitable participation by all stakeholders.

## 12.2 Core Principles

### 12.2.1 Consent Decision-Making

The Company and each Series shall use consent decision-making rather than majority voting for policy decisions. Consent means that a decision can be made when none of the participants has a reasoned and paramount objection to a proposed decision.

Key aspects of consent decision-making include:

* A proposal is presented clearly with adequate background information
  
* Clarifying questions are asked and answered
  
* Reactions to the proposal are shared
  
* The proposal may be amended based on feedback
  
* Objections are raised, discussed, and resolved
  
* Consent is achieved when no objections remain

### 12.2.2 Circular Organization

The Company and each Series shall organize governance into interconnected circles, where:

* Each circle has a defined aim and domain of authority
  
* Circles are connected through double-linking (two people connecting adjacent circles)
  
* Higher-level circles determine the aims and domains of lower-level circles
  
* Lower-level circles determine how to implement their aims within their domains

### 12.2.3 Double-Linking

Communication and alignment between circles shall be maintained through double-linking, where:

* An operational leader from a lower circle is a full member of the next higher circle
  
* A representative elected by the lower circle is a full member of the next higher circle
  
* Both links participate fully in the decision-making of both circles

### 12.2.4 Elections by Consent

Leaders, representatives, and people filling functional roles shall be elected by consent after open discussion, rather than by competitive voting or appointment.

## 12.3 Circle Structure

### 12.3.1 Board Circle

The Board shall function as the top circle in the Company's governance structure, with responsibilities as defined in Article IV.

### 12.3.2 Series Governance Circles

Each Series shall establish appropriate governance circles as determined by the Series Manager(s), which may include:

* Strategic Circle - focusing on long-term direction and major decisions
  
* Operational Circle - focusing on day-to-day operations and implementation
  
* Specific Domain Circles - focusing on particular functions or aspects of the Series business

### 12.3.3 Circle Autonomy

Each circle shall have autonomy within its defined domain, subject to the constraints established by higher circles and this Agreement.

## 12.4 Decision-Making Process

### 12.4.1 Proposal Formation

Proposals may be generated by any member of a circle and should be:

* Clearly stated in writing
  
* Supported by relevant background information
  
* Connected to the circle's aim and domain
  
* Presented with adequate time for consideration

### 12.4.2 Consent Process

The standard consent process shall include:

* Presentation of the proposal
  
* Clarifying questions round
  
* Quick reactions round
  
* Amendments to the proposal if needed
  
* Consent round (asking for objections)
  
* Integration of objections
  
* Final consent round

### 12.4.3 Operational Decisions

Day-to-day operational decisions may be made by the appropriate role-holders without going through the full consent process, provided that:

* The decisions fall within the role-holder's domain
  
* The decisions do not conflict with existing policy
  
* The role-holder is willing to reconsider the decision if concerns are raised

## 12.5 Roles and Responsibilities

### 12.5.1 Required Circle Roles

Each governance circle shall at minimum have the following roles:

* **Circle Leader** - accountable for the circle achieving its aim, allocating resources, and assigning operational roles
  
* **Facilitator** - leads the circle meetings and decision-making processes
  
* **Secretary** - schedules meetings, maintains records, and ensures transparency
  
* **Representative** - represents the circle's interests in the next higher circle

### 12.5.2 Role Selection

All roles shall be filled through election by consent within the circle, with the exception of the Circle Leader, who may be appointed by the next higher circle.

### 12.5.3 Role Reviews

Performance in roles shall be regularly reviewed by the circle to ensure effectiveness and provide feedback for improvement.

## 12.6 Meetings

### 12.6.1 Regular Circle Meetings

Each governance circle shall meet regularly (at least quarterly) to:

* Review progress toward objectives
  
* Make policy decisions
  
* Address tensions or issues
  
* Conduct elections as needed
  
* Allocate resources

### 12.6.2 Meeting Formats

Circle meetings shall follow a structured format that typically includes:

* Opening round - personal check-in and meeting readiness
  
* Administrative matters - consent to agenda and previous minutes
  
* Content items - addressing tensions, making decisions
  
* Closing round - meeting evaluation and personal reflection

### 12.6.3 Facilitation

All governance meetings shall be facilitated to ensure:

* Equality of voice
  
* Focus on the circle's aim
  
* Efficient use of time
  
* Adherence to the consent process
  
* Documentation of decisions

## 12.7 Continuous Improvement

### 12.7.1 Circle Self-Evaluation

Each circle shall periodically evaluate its own effectiveness and make improvements to its structure and processes.

### 12.7.2 Policy Review

All policies shall be reviewed on a scheduled basis to ensure they remain relevant and effective.

### 12.7.3 Governance Audits

The Company shall conduct periodic governance audits to ensure that sociocracy principles are being properly implemented throughout the organization.

## 12.8 Integration with FairShares Model

The sociocratic governance structure shall be integrated with the FairShares membership model described in Article VIII to ensure that:

* All membership classes have appropriate representation in the governance structure
  
* The interests of different stakeholder groups are balanced
  
* Decision-making authority is distributed based on both stake and competence
