# ARTICLE V - SERIES STRUCTURE

## 5.1 Establishment of Series

Pursuant to Section 101.601 of the TBOC, the Company hereby establishes and shall maintain one or more designated Series, each of which:

* Has separate rights with respect to specified property, obligations, profits, and losses associated with the Series
* Has separate powers with respect to specified property, obligations, profits, and losses associated with the Series
* Has separate duties with respect to specified property, obligations, profits, and losses associated with the Series
  
* May have a separate business purpose or investment objective
  
* Shall maintain records to account for the assets and liabilities associated with the Series separate and apart from the assets and liabilities of the Company or any other Series
  
* Shall have liability protection such that the:
  - debts
  - liabilities
  - obligations
  - and expenses

incurred, contracted for, or otherwise existing with respect to a particular Series shall be enforceable against the assets of that Series only, and not against the assets of the Company generally or any other Series

## 5.2 Series Types

The Company shall establish the following types of Series:

### 5.2.1 Asset Management Series

Asset Management Series are established to hold, manage, or operate specific assets or investments for the benefit of designated beneficiaries. Asset Management Series may own real property, equipment, intellectual property, investment portfolios, or other assets.

### 5.2.2 Operating Series

Operating Series are established to conduct business operations, including providing services, manufacturing products, or engaging in commercial activities. Operating Series may enter into contracts, hire employees, and engage in marketing and sales activities.

### 5.2.3 Cell Series

Cell Series are established to serve as holding structures for the benefit of family offices, trusts, or similar arrangements. Cell Series may establish subsidiaries, hold ownership interests in other entities, and make investments.

## 5.3 Initial Series

The Company hereby establishes the following Initial Series, which shall continue in perpetuity unless dissolved in accordance with this Agreement:

1. **Known Element Enterprises LLC** (Operating Series) - Established to provide technology consulting services, software development, and related technical services as further described in Schedule A.

2. **The Campus Trading Company LLC** (Operating Series) - Established to provide educational services, training programs, and related services as further described in Schedule B.

3. **Redwood Family Office Group LLC** (Cell Series) - Established to serve as a holding structure for the benefit of the Redwood family.

4. **Redwood Springs Capital Partners Group LLC** (Cell Series) - Established to serve as a holding structure for investments and ventures affiliated with Redwood Springs Capital Partners.

5. **Wyble Family Office Group LLC** (Cell Series) - Established to serve as a holding structure for the benefit of the Wyble family.

## 5.4 Series Designation

For each Series established under this Agreement, the Board shall adopt a Series Designation, which shall include:

* The name of the Series
  
* The type of Series:
  - Asset Management
  - Operating
  - Cell
  
* The specific purpose and powers of the Series
  
* The name(s) of the initial Manager(s) of the Series
  
* Any specific limitations or restrictions on the Series
  
* Any additional terms applicable to the Series

The Series Designations for the Initial Series are set forth in the attached Schedules.

## 5.5 Series Managers

Each Series shall be managed by one or more Series Managers appointed by the Board. Series Managers shall have full authority to manage the business and affairs of their respective Series, subject to the limitations set forth in this Agreement and the applicable Series Designation.

### 5.5.1 Powers of Series Managers

The Series Managers shall have the power and authority to:

* Conduct the day-to-day operations of the Series
  
* Enter into contracts and agreements on behalf of the Series
  
* Hire and terminate employees and engage independent contractors
  
* Open and maintain bank accounts and investment accounts
  
* Acquire, manage, and dispose of:
  - Real property
  - Equipment
  - Intellectual property
  - Investment portfolios
  - Other Series assets
  
* Obtain financing and incur indebtedness on behalf of the Series
  
* Take any other action necessary or appropriate for the management and operation of the Series

### 5.5.2 Limitations on Series Managers

Series Managers shall not have the power or authority to:

* Take any action that would violate this Agreement or the Series Designation
  
* Commingle assets of the Series with assets of the Company or any other Series
  
* Transfer assets of the Series to the Company or any other Series without proper documentation and consideration
  
* Engage in any transaction that would jeopardize the liability protection of the Series
  
* Merge or consolidate the Series with any other entity without Board approval
  
* Dissolve or terminate the Series without Board approval
  
* Grant capital interests in the Series (only profit interests may be granted)

## 5.6 Series Membership

Each Series may have its own Members who hold Series Interests in that specific Series. Membership in one Series does not confer any rights with respect to any other Series.

### 5.6.1 Series Membership Classes

Each Series shall implement the FairShares membership model described in Article VIII, with a minimum of three membership classes (Class A, Class B, and Class C).

### 5.6.2 Admission of Series Members

The Series Manager(s) may admit new Members to a Series by:

* Issuing Profit Interests to the new Member
  
* Obtaining the new Member's signature on a joinder to this Agreement
  
* Recording the new Member's information in the Series records

### 5.6.3 No Capital Interests

No Series shall issue capital interests. All Series Interests issued to Members shall be Profit Interests only, entitling the Member to share in profits and appreciation occurring after the date of issuance.

## 5.7 Series Records

Each Series shall maintain separate records, accounts, and financial statements for its operations. Such records shall include:

* A current list of the names and addresses of all Series Members
  
* A copy of this Agreement and the applicable Series Designation
  
* Copies of the Series' tax returns and financial statements
  
* Records of all transactions involving the Series' assets
  
* Minutes of any meetings of Series Members
  
* Records of all contributions and distributions

## 5.8 Series Assets and Liabilities

### 5.8.1 Series Assets

Assets associated with a Series shall be recorded in the records of that Series and clearly identified as belonging to that Series. Such identification may be made by:

* Records maintained for the Series
  
* Account statements for the Series
  
* Designation in the title or deed for the asset
  
* Any other method that reasonably identifies the asset as belonging to the Series

### 5.8.2 Series Liabilities

All contracts, agreements, and instruments creating liabilities of a Series shall include a conspicuous statement substantially similar to the following:

"The obligations under this [contract/agreement/instrument] are the obligations of [Name of Series] only and are not the obligations of Turnkey Network Systems LLC generally or any other Series thereof. The assets of [Name of Series] only are available to satisfy these obligations."

## 5.9 Establishment of Additional Series

The Board may establish additional Series by:

* Adopting a Series Designation setting forth the information required by Section 5.4
  
* Filing any required notice or amendment with the Secretary of State of Texas
  
* Appointing one or more Series Managers
  
* Allocating assets and liabilities to the Series
  
* Creating appropriate records for the Series

## 5.10 Dissolution of Series

A Series shall be dissolved and its affairs wound up upon the first to occur of:

* The board's determination that the Series should be dissolved
  
* The occurrence of any event specified in the Series Designation as triggering dissolution
  
* The entry of a judicial decree of dissolution

Upon dissolution, the Series Manager(s) shall wind up the Series' affairs, liquidate its assets, pay its liabilities, and distribute any remaining assets to the Series Members in accordance with their respective interests.
